==> sociewiki-0_5_5.tgz: sociewiki-0.5.5/resources/config.php <==
<?php
//֤ˤäɬꤷƲ
define("SITE_NAME", "WikiȤ̾");
define("SITE_SUBTITLE", "ȥåץڡSITE_NAMEȶɽ륵֥ȥ");
define("URL_BASE", "http://WikiȤURL");
//֤ˤäɬꤷƲ

define("DATA_DIR", "data/");
define("METADATA_DIR", "metadata/");
define("TMP_DIR", METADATA_DIR);
define("RSS_BASE_URL", URL_BASE);
define("RSS_DIR", "./");
define("RECENT_CHANGES_RSS_NAME", "recent_changes.rdf");
define("RECENT_COMMENTS_RSS_NAME", "recent_comments.rdf");
define("RECENT_CHANGES_RSS_PATH", RSS_DIR . RECENT_CHANGES_RSS_NAME);
define("RECENT_COMMENTS_RSS_PATH", RSS_DIR . RECENT_COMMENTS_RSS_NAME);
define("RECENT_CHANGES_RSS_URL", RSS_BASE_URL . RECENT_CHANGES_RSS_NAME);
define("RECENT_COMMENTS_RSS_URL", RSS_BASE_URL . RECENT_COMMENTS_RSS_NAME);

//ڡեޥåȤʸִ˻ѤޥåʥС
define("MARKER1", "\x08");
define("MARKER2", "\x09");

define("QUEUE_MAX_LOG_SIZE", 30);
define("DEFAULT_COMMENT_NUMBER", 5);
define("DEFAULT_RECENT_LIST_NUMBER", 20);
define("RSS_COMMENT_LINE_NUMBER", 3);

define("DEFAULT_THEME", "mono");
define("DEFAULT_FORMLETS", 'Calendar,RecentList,MyPage');

// ȥåץڡɽWikiڡ̾
define("WELCOME_USERS", "WelcomeUsers");
define("WELCOME_VISITORS", "WelcomeVisitors");

# Ⱦѱѿ
$alphanum = '[a-zA-Z0-9]';
# ѤҤ餬 [-]
$hiragana = '(?:\xA4[\xA1-\xF3])';
# ѥ [-]
$katakana = '(?:\xA5[\xA1-\xF6]|\xA1[\xA6\xBC\xB3\xB4])';
# Ѵ졢
$kanji = '(?:[\xB0-\xCE\xD0-\xF3][\xA1-\xFE]|\xCF[\xA1-\xD3])'; # 16-46,48-83,47

# 桼IDڡ̾˻Ѳǽʸ
define("NAME_PAT", "/^(?:$alphanum|$hiragana|$katakana|$kanji){3,29}$/");
define("URL_PAT", '/(http|https|ftp):[^\x00-\x20()<>\x7F-\xFF]*/');
?>

==> sociewiki-0_6_3.tgz: sociewiki-0.6.3/resources/config.php <==
<?php
//֤ˤäɬꤷƲ
define("SITE_NAME", "WikiȤ̾");
define("SITE_SUBTITLE", "ȥåץڡSITE_NAMEȶɽ륵֥ȥ");
define("URL_BASE", "http://WikiȤURL/");
//֤ˤäɬꤷƲ

define("DATA_DIR", "data/");
define("METADATA_DIR", "metadata/");
define("TMP_DIR", METADATA_DIR);
define("RSS_BASE_URL", URL_BASE);
define("RSS_DIR", "rss/");
define("RECENT_CHANGES_RSS_NAME", "recent_changes.rdf");
define("RECENT_COMMENTS_RSS_NAME", "recent_comments.rdf");
define("RECENT_CHANGES_RSS_PATH", RSS_DIR . RECENT_CHANGES_RSS_NAME);
define("RECENT_COMMENTS_RSS_PATH", RSS_DIR . RECENT_COMMENTS_RSS_NAME);
define("RECENT_CHANGES_RSS_URL", RSS_BASE_URL . RECENT_CHANGES_RSS_NAME);
define("RECENT_COMMENTS_RSS_URL", RSS_BASE_URL . RECENT_COMMENTS_RSS_NAME);

//ڡեޥåȤʸִ˻ѤޥåʥС
define("MARKER1", "\x08");
define("MARKER2", "\x09");

define("QUEUE_MAX_LOG_SIZE", 30);
define("DEFAULT_COMMENT_NUMBER", 5);
define("DEFAULT_RECENT_LIST_NUMBER", 20);
define("RSS_COMMENT_LINE_NUMBER", 3);

define("DEFAULT_THEME", "mono");
define("DEFAULT_FORMLETS", 'Calendar,RecentList,MyPage');

// ȥåץڡɽWikiڡ̾
define("WELCOME_USERS", "WelcomeUsers");
define("WELCOME_VISITORS", "WelcomeVisitors");

# Ⱦѱѿ
$alphanum = '[a-zA-Z0-9]';
# ѤҤ餬 [-]
$hiragana = '(?:\xA4[\xA1-\xF3])';
# ѥ [-]
$katakana = '(?:\xA5[\xA1-\xF6]|\xA1[\xA6\xBC\xB3\xB4])';
# Ѵ졢
$kanji = '(?:[\xB0-\xCE\xD0-\xF3][\xA1-\xFE]|\xCF[\xA1-\xD3])'; # 16-46,48-83,47

# 桼IDڡ̾˻Ѳǽʸ
define("NAME_PAT", "/^(?:$alphanum|$hiragana|$katakana|$kanji){3,29}$/");
define("URL_PAT", '/(http|https|ftp):[^\x00-\x20()<>\x7F-\xFF]*/');
?>
